==> pygpt_net-2.5.31.tar.gz: pygpt_net-2.5.31/src/pygpt_net/controller/plugins/settings.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# ================================================== #
# This file is a part of PYGPT package               #
# Website: https://pygpt.net                         #
# GitHub:  https://github.com/szczyglis-dev/py-gpt   #
# MIT License                                        #
# Created By  : Marcin Szczygliński                  #
# Updated Date: 2025.06.30 02:00:00                  #
# ================================================== #

from typing import Any

from pygpt_net.core.events import Event
from pygpt_net.utils import trans


class Settings:
    def __init__(self, window=None):
        """
        Plugin settings controller

        :param window: Window instance
        """
        self.window = window
        self.config_dialog = False
        self.config_initialized = False
        self.current_plugin = None
        self.width = 800
        self.height = 500

    def setup(self):
        """Set up plugin settings"""
        idx = None
        # restore previous selected or restored tab on dialog create
        if 'plugin.settings' in self.window.ui.tabs:
            idx = self.window.ui.tabs['plugin.settings'].currentIndex()
        self.window.plugin_settings.setup(idx)  # widget dialog Plugins

    def toggle_editor(self):
        """Toggle plugin settings dialog"""
        if self.config_dialog:
            self.close()
        else:
            self.open()

    def open(self):
        """Open plugin settings dialog"""
        if not self.config_initialized:
            self.setup()
            self.config_initialized = True
        if not self.config_dialog:
            self.init()
            self.window.ui.dialogs.open(
                'plugin_settings',
                width=self.width,
                height=self.height
            )
            self.config_dialog = True

    def open_plugin(self, id: str):
        """
        Open plugin settings dialog

        :param id: plugin id
        """
        self.current_plugin = id
        self.open()

    def init(self):
        """Initialize plugin settings options"""
        # select the first plugin on list if no plugin selected yet
        if self.current_plugin is None:
            if len(self.window.core.plugins.plugins) > 0:
                self.current_plugin = list(self.window.core.plugins.plugins.keys())[0]

        # assign plugins options to config dialog fields
        for id in self.window.core.plugins.plugins.keys():
            plugin = self.window.core.plugins.plugins[id]
            options = plugin.setup()  # get plugin options

            # load and apply options to config dialog
            self.window.controller.config.load_options('plugin.' + id, options)

        self.window.controller.layout.restore_plugin_settings()  # restore previous selected plugin tab

    def refresh_option(self, id: str, key: str):
        """
        Refresh plugin option

        :param id: plugin id
        :param key: option key
        """
        if id not in self.window.core.plugins.plugins:
            return
        if key not in self.window.core.plugins.plugins[id].options:
            return
        option = self.window.core.plugins.plugins[id].options[key]  # get option
        self.window.controller.config.placeholder.apply(option)  # update keys in option
        items = option["keys"] if "keys" in option else {}
        self.window.controller.config.update_list(
            option=option,
            parent_id='plugin.' + id,
            key=key,
            items=items,
        )

    def save(self):
        """Save plugin settings"""
        for id in self.window.core.plugins.plugins.keys():
            plugin = self.window.core.plugins.plugins[id]
            options = plugin.setup()  # get plugin options

            # add plugin to global config data if not exists
            if id not in self.window.core.config.get('plugins'):
                self.window.core.config.data['plugins'][id] = {}

            # update config with new values
            for key in options:
                value = self.window.controller.config.get_value(
                    parent_id='plugin.' + id, 
                    key=key, 
                    option=options[key],
                )
                self.window.core.plugins.plugins[id].options[key]['value'] = value
                self.window.core.config.data['plugins'][id][key] = value

            # remove key from config if plugin option not exists
            for key in list(self.window.core.config.data['plugins'].keys()):
                if key not in self.window.core.plugins.plugins:
                    self.window.core.config.data['plugins'].pop(key)

        # save preset
        self.window.controller.plugins.presets.save_current()

        # save config
        self.window.core.config.save()
        self.close()
        self.window.update_status(trans('info.settings.saved'))

        # dispatch on update event
        event = Event(Event.PLUGIN_SETTINGS_CHANGED)
        self.window.dispatch(event)
        self.window.controller.ui.update_tokens()  # update tokens (if cmd syntax changed)

    def close(self):
        """Close plugin settings dialog"""
        if self.config_dialog:
            self.window.ui.dialogs.close('plugin_settings')
            self.config_dialog = False

    def load_defaults_user(self, force: bool = False):
        """
        Load plugin settings user defaults

        :param force: force load defaults
        """
        if not force:
            self.window.ui.dialogs.confirm(
                type='plugin.settings.defaults.user', 
                id=-1,
                msg=trans('dialog.plugin.settings.defaults.user.confirm'),
            )
            return

        # reload settings window
        self.init()
        # self.window.ui.dialogs.alert(trans('dialog.plugin.settings.defaults.user.result'))

    def load_defaults_app(self, force: bool = False):
        """
        Load plugin settings app defaults

        :param force: force load defaults
        """
        if not force:
            self.window.ui.dialogs.confirm(
                type='plugin.settings.defaults.app',
                id=-1,
                msg=trans('dialog.plugin.settings.defaults.app.confirm'),
            )
            return

        # restore default options
        self.window.core.plugins.restore_options(self.current_plugin)

        # reload settings window
        self.init()
        self.window.ui.dialogs.alert(trans('dialog.plugin.settings.defaults.app.result'))

    def get_option(self, id: str, key: str) -> Any:
        """
        Get plugin option

        :param id: plugin id
        :param key: option key
        :return: option value
        """
        return self.window.core.plugins.plugins[id].options[key]

==> pygpt_net-2.6.5.tar.gz: pygpt_net-2.6.5/src/pygpt_net/controller/plugins/settings.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# ================================================== #
# This file is a part of PYGPT package               #
# Website: https://pygpt.net                         #
# GitHub:  https://github.com/szczyglis-dev/py-gpt   #
# MIT License                                        #
# Created By  : Marcin Szczygliński                  #
# Updated Date: 2025.08.15 03:00:00                  #
# ================================================== #

from typing import Any

from pygpt_net.core.events import Event
from pygpt_net.utils import trans


class Settings:
    def __init__(self, window=None):
        """
        Plugin settings controller

        :param window: Window instance
        """
        self.window = window
        self.config_dialog = False
        self.config_initialized = False
        self.current_plugin = None
        self.width = 800
        self.height = 500

    def setup(self):
        """Set up plugin settings"""
        idx = None
        if 'plugin.settings' in self.window.ui.tabs:
            idx = self.window.ui.tabs['plugin.settings'].currentIndex()
        self.window.plugin_settings.setup(idx)

    def toggle_editor(self):
        """Toggle plugin settings dialog"""
        if self.config_dialog:
            self.close()
        else:
            self.open()

    def open(self):
        """Open plugin settings dialog"""
        if not self.config_initialized:
            self.setup()
            self.config_initialized = True
        if self.config_dialog:
            return
        self.init()
        self.window.ui.dialogs.open(
            'plugin_settings',
            width=self.width,
            height=self.height
        )
        self.config_dialog = True

    def open_plugin(self, id: str):
        """
        Open plugin settings dialog

        :param id: plugin id
        """
        self.current_plugin = id
        self.open()

    def init(self):
        """Initialize plugin settings options"""
        plugins = self.window.core.plugins.plugins
        if self.current_plugin is None and plugins:
            self.current_plugin = next(iter(plugins))
        cfg = self.window.controller.config
        for pid, plugin in plugins.items():
            options = plugin.setup()
            cfg.load_options(f'plugin.{pid}', options)
        self.window.controller.layout.restore_plugin_settings()

    def refresh_option(self, id: str, key: str):
        """
        Refresh plugin option

        :param id: plugin id
        :param key: option key
        """
        plugins = self.window.core.plugins.plugins
        plugin = plugins.get(id)
        if not plugin:
            return
        options = plugin.options
        if key not in options:
            return
        option = options[key]
        self.window.controller.config.placeholder.apply(option)
        items = option.get("keys", {})
        self.window.controller.config.update_list(
            option=option,
            parent_id=f'plugin.{id}',
            key=key,
            items=items,
        )

    def save(self):
        """Save plugin settings"""
        window = self.window
        plugins = window.core.plugins.plugins
        controller_cfg = window.controller.config
        config_data = window.core.config.data
        plugins_cfg = config_data.setdefault('plugins', {})

        for pid, plugin in plugins.items():
            options = plugin.setup()
            dst = plugins_cfg.setdefault(pid, {})
            for key, opt in options.items():
                value = controller_cfg.get_value(
                    parent_id=f'plugin.{pid}',
                    key=key,
                    option=opt,
                )
                plugin.options[key]['value'] = value
                dst[key] = value

        stale = set(plugins_cfg.keys()) - set(plugins.keys())
        for pid in stale:
            plugins_cfg.pop(pid, None)

        window.controller.plugins.presets.save_current()
        window.core.config.save()
        self.close()
        window.update_status(trans('info.settings.saved'))

        event = Event(Event.PLUGIN_SETTINGS_CHANGED)
        window.dispatch(event)
        window.controller.ui.update_tokens()

    def close(self):
        """Close plugin settings dialog"""
        if self.config_dialog:
            self.window.ui.dialogs.close('plugin_settings')
            self.config_dialog = False

    def load_defaults_user(self, force: bool = False):
        """
        Load plugin settings user defaults

        :param force: force load defaults
        """
        if not force:
            self.window.ui.dialogs.confirm(
                type='plugin.settings.defaults.user',
                id=-1,
                msg=trans('dialog.plugin.settings.defaults.user.confirm'),
            )
            return
        self.init()

    def load_defaults_app(self, force: bool = False):
        """
        Load plugin settings app defaults

        :param force: force load defaults
        """
        if not force:
            self.window.ui.dialogs.confirm(
                type='plugin.settings.defaults.app',
                id=-1,
                msg=trans('dialog.plugin.settings.defaults.app.confirm'),
            )
            return
        self.window.core.plugins.restore_options(self.current_plugin)
        self.init()
        self.window.ui.dialogs.alert(trans('dialog.plugin.settings.defaults.app.result'))

    def get_option(self, id: str, key: str) -> Any:
        """
        Get plugin option

        :param id: plugin id
        :param key: option key
        :return: option value
        """
        return self.window.core.plugins.plugins[id].options[key]
